@@ -475,7 +475,7 @@ bootstrap.late<-function(y,d,z,x,boot=1999,trim=0.05, LATT=FALSE, logit=FALSE, c
 }
 
 
-effects.late.x<-function(y,d,m,zd,  x, zm, trim=0.05, csquared=FALSE, bwreg=bwreg, bwm=bwm, cminobs=40, logit=FALSE){
+effects_late_x<-function(y,d,m,zd,  x, zm, trim=0.05, csquared=FALSE, bwreg=bwreg, bwm=bwm, cminobs=40, logit=FALSE){
   if (is.null(bwreg) | is.null(bwm)) temp<-npcdensbw(ydat=m, xdat=data.frame(zm,x), ckertype="gaussian", bwmethod="normal-reference")
   if (is.null(bwreg))  bwreg<-temp$xbw
   if (is.null(bwm))  bwm<-temp$ybw
@@ -561,7 +561,7 @@ bootstrap.mediation.late.x<-function(y,d,m,zd,zm,x, boot=1999,trim=0.05, csquare
       if (is.null(ncol(zm))==0) zmb<-zm[sboot,]
       if (is.null(ncol(x))) xb<-x[sboot]
       if (is.null(ncol(x))==0) xb<-x[sboot,]
-      bsamples[i,]=effects.late.x(y=yb,d=db,m=mb,zd=zdb, zm=zmb, x=xb, trim=trim, csquared=csquared, bwreg=bwreg, bwm=bwm, cminobs=cminobs, logit=logit)
+      bsamples[i,]=effects_late_x(y=yb,d=db,m=mb,zd=zdb, zm=zmb, x=xb, trim=trim, csquared=csquared, bwreg=bwreg, bwm=bwm, cminobs=cminobs, logit=logit)
     }
   }
 
@@ -583,7 +583,7 @@ bootstrap.mediation.late.x<-function(y,d,m,zd,zm,x, boot=1999,trim=0.05, csquare
         if (is.null(ncol(zm))) zmb<-c(zmb,zm[key==sboot[k]])
         if (is.null(ncol(zm))==0) zmb=rbind(zmb,zm[key==sboot[k],])
       }
-      est=effects.late.x(y=yb,d=db,m=mb,zd=zdb, zm=zmb, x=xb, trim=trim, csquared=csquared, bwreg=bwreg, bwm=bwm, cminobs=cminobs, logit=logit)
+      est=effects_late_x(y=yb,d=db,m=mb,zd=zdb, zm=zmb, x=xb, trim=trim, csquared=csquared, bwreg=bwreg, bwm=bwm, cminobs=cminobs, logit=logit)
       bsamples<-rbind(bsamples, est)
       temp<-c(temp,1)
     }
@@ -1822,90 +1822,3 @@ rdd.x.boot<-function(y,z,x, bw0, bw1, bwz, boot=1999, regtype){
   }
   mc
 }
-
-MLmean = function(y, x, d, MLmethod = "lasso", k = 3, zeta, seed){
-  ybin <- 1*(length(unique(y))==2 & min(y)==0 & max(y)==1)  # check if binary outcome
-  x <- data.frame(x)
-  stepsize <- ceiling((1/k)*length(d))
-  set.seed(seed)
-  idx <- sample(length(d), replace=FALSE)
-  score <- c()
-  # cross-fitting procedure that splits sample in training and testing data
-  for (i in 1:k){
-    tesample <- idx[((i-1)*stepsize+1):(min((i)*stepsize,length(d)))]
-    trsample <- idx[-tesample]
-    eydx <- MLfunct(y = y[trsample], x = x[trsample,], MLmethod = MLmethod, ybin = ybin)
-    eydxte <- predict(eydx, x[tesample,], onlySL = TRUE)$pred  #predict conditional outcome in test data
-    score <- rbind(score, cbind(eydxte,zeta[tesample]))
-  }
-  score <- score[order(idx),]
-  score
-}
-
-
-hdtest = function(y1, y0, d, x, trim = 0.01, MLmethod = "lasso", k = 3) {
-
-  # Check if the outcome is binary
-  ybin = 1 * (length(unique(y1)) == 2 & min(y1) == 0 & max(y1) == 1 &
-                length(unique(y0)) == 2 & min(y0) == 0 & max(y0) == 1)
-
-  ## Convert vectors to data frames for processing
-  # Dataframe with covariates for did nuisance parameters
-  x = data.frame(x)
-
-  # Dataframe with covariates and outcome in period 0 for selobs nuisance parameters
-  xy0 = data.frame(x, y0)
-
-  # Counterfactual treatment status
-  d0 = 1 - d
-
-  # Difference in outcome period 0 to period 1
-  y10 = y1 - y0
-
-  # Calculate the step size for cross-validation splits
-  stepsize = ceiling((1 / k) * length(d))
-  set.seed(1)
-  idx = sample(length(d), replace = FALSE)
-
-  # Initialize an empty vector to store nuisance parameters
-  nuisance = c()
-
-  # Cross-fitting procedure to split sample into training and testing data
-  for (i in 1:k) {
-    tesample = idx[((i - 1) * stepsize + 1):(min(i * stepsize, length(d)))]
-    trsample = idx[-tesample]
-
-    # Estimate OOB-propensity scores
-    # Selobs: train propensity score learner
-    p = MLfunct(y = d[trsample], x = xy0[trsample, ], MLmethod = MLmethod, ybin = 1)
-
-    # Selobs: predict OOB propensity scores
-    pte = predict(p, xy0[tesample, ], onlySL = TRUE)$pred
-
-    # Did: train propensity score learner
-    pi = MLfunct(y = d[trsample], x = x[trsample, ], MLmethod = MLmethod, ybin = 1)
-
-    # Did: predict OOB propensity scores
-    pite = predict(pi, x[tesample, ], onlySL = TRUE)$pred
-
-    # Estimate OOB-conditional outcome
-    # Selobs: train conditional outcome learner
-    mu = MLfunct(y = y1[trsample], x = xy0[trsample, ], d1 = d0[trsample], MLmethod = MLmethod, ybin = ybin)
-
-    # Selobs: predict OOB conditional outcome learner
-    mute = predict(mu, xy0[tesample, ], onlySL = TRUE)$pred
-
-    # Did: train conditional outcome learner
-    m = MLfunct(y = y10[trsample], x = x[trsample, ], d1 = d0[trsample], MLmethod = MLmethod, ybin = ybin)
-
-    # Selobs: predict OOB conditional outcome learner
-    mte = predict(m, x[tesample, ], onlySL = TRUE)$pred
-
-    # Find observations not satisfying trimming restriction
-    trimmed = 1 * ((pte > 1 - trim) | (pite > 1 - trim))
-    nuisance = rbind(nuisance, cbind(d[tesample], y1[tesample], y0[tesample], pte, pite, mute, mte, trimmed))
-  }
-
-  nuisance = nuisance[sort(idx), ]
-  return(nuisance)
-}
